<?xml version="1.0" encoding="UTF-8"?>
<app>

<category>
Audio
</category>

<name>
DeaDBeeF
</name>

<description>
   <am>simple audio player</am>
   <ar>simple audio player</ar>
   <be>simple audio player</be>
   <bg>simple audio player</bg>
   <bn>simple audio player</bn>
   <ca>Senzill reproductor d'àudio</ca>
   <cs>simple audio player</cs>
   <da>Simpel lydafspiller</da>
   <de>Einfacher Audio-Player</de>
   <el>Απλή συσκευή αναπαραγωγής ήχου</el>
   <en>simple audio player</en>
   <es_ES>Reproductor de audio sencillo</es_ES>
   <es>Reproductor de audio sencillo</es>
   <et>simple audio player</et>
   <eu>simple audio player</eu>
   <fa>simple audio player</fa>
   <fil_PH>simple audio player</fil_PH>
   <fi>yksinkertainen audiosoitin</fi>
   <fr_BE>Lecteur audio basique</fr_BE>
   <fr>Lecteur audio basique</fr>
   <gl_ES>reprodutor de audio simple</gl_ES>
   <gu>simple audio player</gu>
   <he_IL>simple audio player</he_IL>
   <hi>सरल ऑडियो प्लेयर</hi>
   <hr>simple audio player</hr>
   <hu>simple audio player</hu>
   <id>simple audio player</id>
   <is>simple audio player</is>
   <it>Lettore di tracce audio semplice</it>
   <ja>シンプルなオーディオプレーヤー</ja>
   <kk>simple audio player</kk>
   <ko>simple audio player</ko>
   <ku>simple audio player</ku>
   <lt>paprastas garso grotuvas</lt>
   <mk>simple audio player</mk>
   <mr>simple audio player</mr>
   <nb_NO>simple audio player</nb_NO>
   <nb>enkel lydavspiller</nb>
   <nl_BE>simple audio player</nl_BE>
   <nl>eenvoudige audio speler</nl>
   <or>simple audio player</or>
   <pl>prosty odtwarzacz audio</pl>
   <pt_BR>Reprodutor de áudio simples</pt_BR>
   <pt>Reprodutor de áudio simples e de fácil utilização</pt>
   <ro>simple audio player</ro>
   <ru>Музыкальный проигрыватель</ru>
   <sk>jednoduchý zvukový prehrávač</sk>
   <sl>preprost predvajalnik zvoka</sl>
   <so>simple audio player</so>
   <sq>Lojtës i thjeshtë audio</sq>
   <sr>simple audio player</sr>
   <sv>enkel ljudspelare</sv>
   <th>โปรแกรมเล่นเสียงอย่างง่าย</th>
   <tr>basit ses çalar</tr>
   <uk>простий аудіо програвач</uk>
   <vi>simple audio player</vi>
   <zh_CN>简单的音频播放器</zh_CN>
   <zh_HK>simple audio player</zh_HK>
   <zh_TW>simple audio player</zh_TW>
</description>

<installable>
32,64
</installable>

<screenshot>http://deadbeef.sourceforge.net/screenshots/0.6/06.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
deadbeef
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
deadbeef
</uninstall_package_names>
</app>
